@@ -4,7 +4,7 @@
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -251,5 +251,15 @@ FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_sync (Fla
                                                                              gboolean            *out_changed,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
+FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_related_refs_sync (FlatpakInstallation *self,
+                                                                                     const char          *remote_name,
+                                                                                     const char          *ref,
+                                                                                     GCancellable        *cancellable,
+                                                                                     GError             **error);
+FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_installed_related_refs_sync (FlatpakInstallation *self,
+                                                                                        const char          *remote_name,
+                                                                                        const char          *ref,
+                                                                                        GCancellable        *cancellable,
+                                                                                        GError             **error);
 
 #endif /* __FLATPAK_INSTALLATION_H__ */
